@@ -25,7 +25,7 @@ import logging
 import mimetypes
 import os
 import re
-from typing import Dict, List, Optional, Union
+from typing import List, Optional
 from moss.ems.utilities import PaginationQuery
 from requests import Response
 
@@ -125,7 +125,7 @@ class EmsLayer(object):
         if not isinstance(features, list):
             raise EmsLayerException("The features have to be of type 'list'.")
 
-        post_data: Dict[str, Union[str, int, list]] = {
+        post_data = {
             "f": "json",
             "features": json.dumps(features),
         }
@@ -217,7 +217,7 @@ class EmsLayer(object):
                 if attribute in exclude_fields:
                     feature["attributes"].pop(attribute, None)
 
-        post_data: Dict[str, Union[str, int, list]] = {
+        post_data = {
             "f": "json",
             "features": json.dumps(features),
         }
